@@ -1,12 +1,12 @@
 import re
-
+from bs4 import BeautifulSoup
 from .easy_words import EASY_WORDS as _EASY_WORDS
 
 
 def pct_unfamiliar_words(text: str) -> float:
     words = _words(text)
     no_possesives = (w.replace("'s", "").replace("s'", "") for w in words)
-    unfamiliar_words = [w for w in no_possesives if w not in _EASY_WORDS]
+    unfamiliar_words = [w for w in no_possesives if _is_unfamiliar(w)]
 
     return len(unfamiliar_words) / len(words)
 
@@ -20,4 +20,14 @@ def avg_sentence_length(text: str) -> float:
 
 
 def _words(in_text: str) -> tuple[str, ...]:
-    return tuple(w.lower().strip('.(),"') for w in in_text.split())
+    plain_text = BeautifulSoup(in_text, "html.parser").text
+
+    return tuple(w.lower().strip('.(),"') for w in plain_text.split())
+
+
+def _is_unfamiliar(word: str) -> bool:
+    match word:
+        case number if re.match(r"\d+$", number):
+            return False
+        case _:
+            return word not in _EASY_WORDS
